@@ -104,9 +104,6 @@ const char *Checks::chkRegister(Line *line, ScriptImage *img)
 	if(scr->access != ScriptInterp::scrPUBLIC)
 		return "cannot register non-public script";
 
-	if(cp)
-		++cp;
-
 	if(ext && !stricmp(ext, ".conf"))
 	{
 		if(cp)
@@ -172,9 +169,6 @@ const char *Checks::chkAssign(Line *line, ScriptImage *img)
 	if(!strnicmp(line->cmd, "incoming.", 9))
 		return "invalid member for incoming"; 
 
-	if(cp && *cp == '.')
-		++cp;
-
 	if(cp)
 	{
 		if(!stricmp(cp, "timeslot"))
@@ -328,9 +322,6 @@ const char *Checks::chkSelect(Line *line, ScriptImage *img)
 trunking:
 	img->setPointer(sbuf, scr);
 
-	if(cp && *cp == '.')
-		++cp;
-
 	if(cp)
 	{
 		if(!stricmp(cp, "timeslot"))
