@@ -35,6 +35,8 @@ char *Bayonne::status = NULL;
 timeout_t Bayonne::step_timer = 20;
 timeout_t Bayonne::reset_timer = 60;
 timeout_t Bayonne::exec_timer = 60000;
+Bayonne::RPCNode *Bayonne::RPCNode::first = NULL;
+unsigned Bayonne::RPCNode::count = 0;
 Bayonne::Traffic Bayonne::total_call_attempts;
 Bayonne::Traffic Bayonne::total_call_complete;
 Mutex Bayonne::Ring::locker;
@@ -50,6 +52,16 @@ AtomicCounter Bayonne::libexec_count = 0;
 unsigned Bayonne::compile_count;
 volatile bool Bayonne::image_loaded = false;
 volatile unsigned short Bayonne::total_active_calls = 0;
+const char *Bayonne::trap_community = "public";
+SOCKET Bayonne::trap_so4 = INVALID_SOCKET;
+unsigned Bayonne::trap_count4 = 0;
+struct sockaddr_in Bayonne::trap_addr4[8];
+
+#ifdef	CCXX_IPV6
+SOCKET Bayonne::trap_so6 = INVALID_SOCKET;
+unsigned Bayonne::trap_count6 = 0;
+struct sockaddr_in6 Bayonne::trap_addr6[8];
+#endif
 
 BayonneTranslator *Bayonne::init_translator = NULL;
 const char *Bayonne::init_voicelib = "none/prompts";
@@ -240,6 +252,20 @@ void Bayonne::Call::start(void)
 		call_connect = time(&buf);
 }
 
+Bayonne::RPCNode::RPCNode(const char *id, RPCDefine *table)
+{
+	prefix = id;
+	methods = table;
+	next = first;
+	first = this;
+
+	while(table && table->name)
+	{
+		++count;
+		++table;
+	}
+}
+	
 Bayonne::Traffic::Traffic()
 {
 	time_t ts;
@@ -274,6 +300,159 @@ void Bayonne::waitLoaded(void)
 	}
 }
 
+void Bayonne::snmptrap(unsigned id, const char *descr)
+{
+	static unsigned char header1_short[] = {
+    	0x06, 0x08, 0x2b, 0x06, 0x01, 0x04, 0x01, 0x81, 0xc7, 0x42,
+    	0x40, 0x04, 0xc0, 0xa8, 0x3b, 0xcd};
+
+	static unsigned char header1_long[] = {
+    	0x06, 0x08, 0x2b, 0x06, 0x01, 0x04, 0x01, 0x81, 0xc7, 0x42,
+    	0x40, 0x04, 0xc0, 0xa8, 0x3b, 0xcd};
+
+	static unsigned char header2[] = {
+    	0x06, 0x08, 0x2b, 0x06, 0x01, 0x02, 0x01, 0x01, 0x01, 0x00, 0x04};
+
+	unsigned idx;
+	socklen_t alen;
+	unsigned char buf[128];
+	unsigned id1 = id, id2 = 0;
+	unsigned len;
+	long timestamp = uptime() * 100l;
+	unsigned offset1 = 7 + strlen(trap_community);
+	unsigned offset2 = offset1 + sizeof(header1_long);
+	unsigned lo1 = 1;
+	unsigned lo2 = offset1 + 1;
+
+	if(id1 > 6)
+	{
+		id2 = id1;
+		id1 = 6;
+	}
+
+    buf[0] = 0x30;
+    buf[2] = 0x02;
+    buf[3] = 0x01;
+    buf[4] = 0x00;
+    buf[5] = 0x04;
+    buf[6] = strlen(trap_community);
+
+    strcpy((char *)(buf + 7), trap_community);
+    buf[offset1] = 0xa4;
+
+    if(descr)
+        memcpy(buf + offset1 + 2, header1_long, sizeof(header1_long));
+    else
+        memcpy(buf + offset1 + 2, header1_short, sizeof(header1_short));
+
+    buf[offset2] = 0x02;
+    buf[offset2 + 1 ] = 0x01;
+    buf[offset2 + 2] = id1;
+    buf[offset2 + 3] = 0x02;
+    buf[offset2 + 4] = 0x01;
+    buf[offset2 + 5] = id2;
+
+    buf[offset2 + 6] = 0x43;
+    buf[offset2 + 7] = 0x04;
+    buf[offset2 + 8] = timestamp / 0x1000000l;
+    buf[offset2 + 9] = (timestamp / 0x10000l) & 0xff;
+    buf[offset2 + 10] = (timestamp / 0x100l) & 0xff;
+    buf[offset2 + 11] = timestamp & 0xff;
+    buf[offset2 + 12] = 0x30;
+
+    if(!descr) {
+        buf[offset2 + 13] = 0x00;
+        len = offset2 + 14;
+        goto send;
+    }
+
+    buf[offset2 + 13] = strlen(descr) + 14;
+    buf[offset2 + 14] = 0x30;
+    buf[offset2 + 15] = strlen(descr) + 12;
+    memcpy(buf + offset2 + 16, header2, sizeof(header2));
+    offset2 += 16 + sizeof(header2);
+    buf[offset2] = strlen(descr);
+    strcpy((char *)(buf + offset2 + 1), descr);
+    len = offset2 + 1 + strlen(descr);
+
+send:
+    buf[lo1] = len - 2;
+    buf[lo2] = len - 15;
+
+	alen = sizeof(struct sockaddr_in);
+	if(trap_so4 != INVALID_SOCKET && trap_count4)
+		for(idx = 0; idx < trap_count4; ++idx)
+			sendto(trap_so4, buf, len, 0, 
+				(struct sockaddr *)&trap_addr4[idx], alen);
+
+#ifdef	CCXX_IPV6
+        alen = sizeof(struct sockaddr_in6);
+        if(trap_so6 != INVALID_SOCKET && trap_count6)
+                for(idx = 0; idx < trap_count6; ++idx)
+                        sendto(trap_so6, buf, len, 0, 
+				(struct sockaddr *)&trap_addr6[idx], alen);
+#endif
+}
+
+void Bayonne::addTrap4(const char *addr)
+{
+	char abuf[128];
+	char *tok;
+	socklen_t alen = sizeof(sockaddr_in);
+	InetAddress ia;
+	int on = 1;
+
+	setString(abuf, sizeof(abuf), addr);
+	addr = strtok_r(abuf, " ;,\r\n\t", &tok);
+	if(trap_so4 == INVALID_SOCKET)
+	{
+		trap_so4 = socket(AF_INET, SOCK_DGRAM, 0);
+		setsockopt(trap_so4, SOL_SOCKET, SO_BROADCAST, &on, sizeof(on));
+	}
+
+	while(addr && trap_count4 < 8)
+	{
+		ia = addr;
+		memset(&trap_addr4[trap_count4], 0, alen);
+		trap_addr4[trap_count4].sin_family = AF_INET;
+		trap_addr4[trap_count4].sin_port = htons(162);
+		trap_addr4[trap_count4].sin_addr = ia.getAddress();	
+		++trap_count4;
+		addr = strtok_r(NULL, " ;,\r\n\t", &tok);
+	}
+}
+
+#ifdef	CCXX_IPV6
+void Bayonne::addTrap6(const char *addr)
+{
+	char abuf[128];
+	char *tok;
+	socklen_t alen = sizeof(sockaddr_in6);
+	IPV6Address ia;
+	int on = 1;
+
+	setString(abuf, sizeof(abuf), addr);
+	addr = strtok_r(abuf, " ;,\r\n\t", &tok);
+	if(trap_so6 == INVALID_SOCKET)
+	{
+		trap_so6 = socket(AF_INET6, SOCK_DGRAM, 0);
+		setsockopt(trap_so6, SOL_SOCKET, SO_BROADCAST, &on, sizeof(on));
+	}
+
+	while(addr && trap_count6 < 8)
+	{
+		ia = addr;
+		memset(&trap_addr6[trap_count6], 0, alen);
+		trap_addr6[trap_count6].sin6_family = AF_INET6;
+		trap_addr6[trap_count6].sin6_port = htons(162);
+		trap_addr6[trap_count6].sin6_addr = ia.getAddress();	
+		++trap_count6;
+		addr = strtok_r(NULL, " ;,\r\n\t", &tok);
+	}
+}
+
+#endif
+
 bool Bayonne::loadPlugin(const char *path)
 {
         char pathbuf[256];
@@ -724,11 +903,17 @@ void Bayonne::down(void)
 
 ScriptCompiler *Bayonne::reload(void)
 {
+	static unsigned trap_id = 0;
+
 	ScriptCompiler *img;
 
 	if(!server)
 		return NULL;
 
+	snmptrap(trap_id, "bayonne server");
+	if(!trap_id)
+		++trap_id;
+	
 	compile_count = 0;
 
 	reloading.writeLock();
