@@ -58,7 +58,7 @@
 #define	MAX_PATHNAME	256
 #define	MIN_AUDIOFEED	(120 * 8)	// 120 millisecond starting
 #define	MAX_AUDIOFEED	(600 * 8)	// 600 millisecond buffer
-#define	RPC_MAX_KEYS	128
+#define	RPC_MAX_PARAMS	96
 
 #ifdef	WIN32
 #define	PFD_INVALID	INVALID_HANDLE_VALUE
@@ -84,6 +84,7 @@ class __EXPORT BayonneSession;
 class __EXPORT BayonneSpan;
 class __EXPORT BayonneService;
 class __EXPORT BayonneTranslator;
+class __EXPORT BayonneRPC;
 	  
 /**
  * Generic Bayonne master class to reference various useful data types
@@ -94,11 +95,26 @@ class __EXPORT BayonneTranslator;
  */
 class __EXPORT Bayonne : public Script
 {
+private:
+	static SOCKET trap_so4;
+	static unsigned trap_count4;
+	static struct sockaddr_in trap_addr4[8];
+
+#ifdef	CCXX_IPV6
+	static SOCKET trap_so6;
+	static unsigned trap_count6;
+	static struct sockaddr_in6 trap_addr6[8];
+#endif
+
 public:
+	static void snmptrap(unsigned id, const char *descr = NULL);
+
 #ifdef	WIN32
 	typedef	WORD	timeslot_t;
+	typedef	DWORD	rpcint_t;
 #else
 	typedef uint16_t timeslot_t;
+	typedef	int32_t	rpcint_t;
 #endif
 
 protected:
@@ -128,6 +144,7 @@ public:
 
 	static BayonneTranslator *init_translator;
 	static const char *init_voicelib;
+	static const char *trap_community;
 	static AtomicCounter libexec_count;
 
 	/**
@@ -506,6 +523,15 @@ public:
 		RESULT_OFFLINE = 255
 	}	result_t;
 
+	typedef	enum
+	{
+		RPC_AUTH_INVALID = 0,
+		RPC_AUTH_NONE,
+		RPC_AUTH_REGISTRY,
+		RPC_AUTH_SYSTEM,
+		RPC_AUTH_ANY
+	}	rpcauth_t;
+
 	typedef	struct
 	{
 		Line line;
@@ -687,6 +713,55 @@ public:
 		volatile unsigned long iCount, oCount;
 	};
 
+	/**
+	 * A rpc method handler.
+	 */
+	typedef void (*rpcmethod_t)(BayonneRPC *rpc);
+
+	/**
+	 * This is a structure used to initialize XMLRPC method tables.
+	 */
+	typedef struct
+	{
+		const char *name;
+		rpcmethod_t method;
+		const char *help;
+		const char *signature;
+	}	RPCDefine;
+
+	/**
+	 * This is a little class used to associate XMLRPC call method
+	 * tables with our server.
+	 */
+	class __EXPORT RPCNode
+	{
+	private:
+		friend class __EXPORT BayonneRPC;
+		static RPCNode *first;
+		static unsigned count;
+		RPCNode *next;
+		RPCDefine *methods;
+		const char *prefix;
+
+	public:
+		inline RPCNode *getFirst(void)
+			{return first;};
+
+		inline RPCNode *getNext(void)
+			{return next;};
+
+		inline const char *getPrefix(void)
+			{return prefix;};
+
+		inline RPCDefine *getMethods(void)
+			{return methods;};
+
+		static inline unsigned getCount(void)
+			{return count;};
+
+		RPCNode(const char *prefix, RPCDefine *dispatch);
+	};
+
 	/**
 	 * The current state handler in effect for a given channel
 	 * to receive events.  This is done by a direct method pointer
@@ -1048,6 +1123,76 @@ public:
 	static void errlog(const char *level, const char *fmt, ...); 
 
 	static bool getUserdata(void);
+
+	static void addTrap4(const char *addr);
+#ifdef	CCXX_IPV6
+	static void addTrap6(const char *addr);
+#endif
+};
+
+/**
+ * This class is used to bind services that are to be published with zeroconf, such
+ * as by the avahi module.
+ *
+ * @author David Sugar <dyfet@gnutelephony.org>
+ * @short Bayonne zerconf binding class.
+ */
+class __EXPORT BayonneZeroconf
+{
+protected:
+	static BayonneZeroconf *zeroconf_first;
+	BayonneZeroconf *zeroconf_next;
+	const char *zeroconf_type;
+	tpport_t zeroconf_port;
+
+public:
+	typedef enum 
+	{
+		ZEROCONF_IPANY,
+		ZEROCONF_IPV6,
+		ZEROCONF_IPV4
+	}	zeroconf_family_t;
+
+protected:
+	zeroconf_family_t zeroconf_family;
+
+	BayonneZeroconf(const char *type, zeroconf_family_t family = ZEROCONF_IPANY);
+
+public:
+	/**
+	 * Get the first zeroconf binding, used by zeroconf plugins.
+	 *
+	 * @return first zeroconf binding.
+	 */
+	static inline BayonneZeroconf *getFirst(void)
+		{return zeroconf_first;};
+
+	/**
+	 * Get the next zeroconf binding to iterate an object list.
+	 *
+	 * @return next zerconf binding.
+	 */
+	inline BayonneZeroconf *getNext(void)
+		{return zeroconf_next;};
+
+	/**
+	 * Get the binding protocol description, usually "_svc._proto".
+	 *
+	 * @return binding description.
+	 */
+	inline const char *getType(void)
+		{return zeroconf_type;};
+
+	/**
+	 * Get the binding service port number.  If 0, then disabled.
+	 *
+	 * @return 0 or port number.
+	 */
+	inline tpport_t getPort(void)
+		{return zeroconf_port;};
+
+	inline zeroconf_family_t getFamily(void)
+		{return zeroconf_family;};
 };
 
 /**
@@ -2776,28 +2921,33 @@ public:
 class __EXPORT BayonneRPC : public Bayonne
 {
 protected:
-        struct {
-                const char *name;
-                const char *field;
-                const char *value;
-        }       rpc_keydata[RPC_MAX_KEYS];
-
-        unsigned rpc_keycount, rpc_argcount;
-
 	BayonneRPC();
 
-        void addArg(const char *value);
-        void addKey(const char *key, const char *value, const char *field = NULL);
+	struct params
+	{
+		char *name[RPC_MAX_PARAMS];
+		char *map[RPC_MAX_PARAMS];
+		char *value[RPC_MAX_PARAMS];
+		unsigned short param[RPC_MAX_PARAMS];
+		unsigned count;
+		short argc;
+	}	params;
+
+	bool parseCall(char *cp);
 
 public:
 	struct {
-		unsigned replycode;		// 200 = ok...
-		const char *replytext;
+		char *buffer;
+		size_t bufsize;
+		size_t bufused;
+		const char *agent_id;
+		const char *protocol;
 		const char *authorization;	// user:secret
-		bool authorized;	// authorized by web server...
-	}	http;
+		rpcauth_t authorized;	// authorized by web server...
+	}	transport;
 
         struct {
+		const char *prefix;	// xmlrpc has prefix, soap NULL
                 const char *method;
                 const char *tranid;
                 const char *action;
@@ -2805,10 +2955,17 @@ public:
         }	header;
 
 	inline unsigned getCount(void)
-		{return rpc_argcount;};
+		{return params.argc;};
 
-        const char *getArg(unsigned id);
-        const char *getKey(const char *name, const char *field = NULL);
+	const char *getIndexed(unsigned short param, unsigned short offset);
+	const char *getNamed(unsigned short param, const char *member);
+	const char *getMapped(const char *map, const char *member);
+
+	bool buildResponse(const char *fmt, ...);
+	void sendSuccess(void);
+	void sendFault(int code, const char *string);
+
+	bool invokeXMLRPC(void);
 };	
 	 
 /**
