@@ -52,6 +52,7 @@ static Keydata::Define driver[] = {
 	{"filler", "false"},
 	{"urlprefix", "sip:"},
 	{"immediate", "yes"},
+	{"zeroconf", "yes"},
 	{"regtype", "friend"},	// default registration type
 	{"starting", "delayed"},
 	{"threads", "5"},
@@ -128,6 +129,7 @@ void SIPThread::run(void)
 
 Driver::Driver() :
 BayonneDriver(driver, "/bayonne/driver/sip", "sip", false),
+BayonneZeroconf("_sip._udp", ZEROCONF_IPV4),
 Thread(atoi(getLast("priority")), atoi(getLast("stack")) * 1024 + 8192),
 Assoc()
 {
@@ -705,11 +707,20 @@ void Driver::startDriver(void)
 			cp = "udp";
 
 		if(!stricmp(cp, "tcp"))
+		{
+			zeroconf_type = "_sip._tcp";
 			rtn = eXosip_listen_addr(IPPROTO_TCP, NULL, sip_port, AF_INET, 0);
+		}
 		else if(!stricmp(cp, "tls"))
+		{
+			zeroconf_type = "_sip._tcp";
 			rtn = eXosip_listen_addr(IPPROTO_TCP, NULL, sip_port, AF_INET, 1);
+		}
 		else
+		{
+			zeroconf_type = "_sip._udp";
 			rtn = eXosip_listen_addr(IPPROTO_UDP, NULL, sip_port, AF_INET, 0);
+		}
 
 		if(!rtn)
 			break;
@@ -725,6 +736,17 @@ void Driver::startDriver(void)
 			rtp_port += 10;
 	}
 
+	cp = getLast("zeroconf");
+	switch(*cp)
+	{
+	case '1':
+	case 'y':
+	case 'Y':
+	case 't':
+	case 'T':
+		zeroconf_port = sip_port;
+	}
+
 	threads = atoi(getLast("threads"));
 
 	cp = getLast("interface");
