@@ -159,7 +159,7 @@ private:
 	SIPThread();
 };
 
-class Driver : public BayonneDriver, public Audio, public Thread, public Assoc
+class Driver : public BayonneDriver, public BayonneZeroconf, public Audio, public Thread, public Assoc
 {
 protected:
 	friend class Session;
