@@ -23,35 +23,119 @@ namespace moduleWebservice {
 using namespace ost;
 using namespace std;
 
+unsigned long Session::htmlAccess(const char *fname)
+{
+	char path[256];
+	struct stat ino;
+	const char *prefix = Service::webservice.getLast("datafiles");
+
+	snprintf(path, sizeof(path), "%s/%s", prefix, fname);
+
+	if(stat(path, &ino))
+		return 0;
+
+	return ino.st_size;
+}
+
+void Session::htmlInsert(const char *path, const char *title)
+{
+	char cbuf[256];
+	FILE *fp;
+	const char *cp;
+	char *dp = buffer;
+	const char *prefix = Service::webservice.getLast("datafiles");
+        const char *sl = sla;
+        unsigned long upt = uptime();
+        char dur[65];
+
+        if(upt < 3600)
+                snprintf(dur, sizeof(dur), "%ld minute(s)", upt / 60);
+        else if(upt < (36000l))
+                snprintf(dur, sizeof(dur), "%ld hour(s), %ld minute(s)",
+                        upt / 3600, (upt / 60) % 60);
+        else if(upt < (360000l))
+                snprintf(dur, sizeof(dur), "%ld hours", upt / 3600);
+        else
+                snprintf(dur, sizeof(dur), "%ld days", upt / (3600l * 24l));
+
+        if(!sl || !*sl)
+                sl = "up";
+
+	snprintf(cbuf, sizeof(cbuf), "%s/%s", prefix, path);
+	fp = fopen(cbuf, "r");
+
+	if(!fp)
+		return;
+
+	while(NULL != fgets(cbuf, sizeof(cbuf), fp))
+	{
+		if(feof(fp))
+			break;
+
+		cp = cbuf;
+		while(*cp)
+		{
+			switch(*cp)
+			{
+			case '\n':
+				*(dp++) = '\r';
+				*(dp++) = '\n';
+			case '\r':
+				++cp;
+				break;
+			case '%':
+				*dp = 0;
+				if(!strncmp(cp, "%title%", 7) && title)
+				{
+					cp += 7;
+					strcpy(dp, title);
+				}	
+				else if(!strncmp(cp, "%version%", 9))
+				{
+					cp += 9;
+					strcpy(dp, VERSION);
+				}
+				else if(!strncmp(cp, "%node%", 6))
+				{
+					cp += 6;
+					strcpy(dp, server->getLast("servername"));
+ 				}
+				else if(!strncmp(cp, "%timeslots%", 11))
+ 				{
+					cp += 11;
+					snprintf(dp, 10, "%d", ts_used);
+				}
+				else if(!strncmp(cp, "%level%", 7))
+				{
+					cp += 7;
+					strcpy(dp, sl);
+				}
+				else if(!strncmp(cp, "%uptime%", 8))
+				{
+					cp += 8;
+					strcpy(dp, dur);
+				}  
+				if(*dp)
+				{
+					dp += strlen(dp);
+					break;
+				} 
+			default:
+				*(dp++) = *(cp++);
+			}
+		}
+	}
+	fclose(fp);
+	*dp = 0;
+	if(dp > buffer)
+		sendText(buffer);
+}
+
 void Session::htmlFooter(void)
 {
-	const char *sl = sla;
-	unsigned long upt = uptime();
-	char dur[65];
-
-	if(upt < 3600)
-		snprintf(dur, sizeof(dur), "%ld minute(s)", upt / 60);
-	else if(upt < (36000l))
-		snprintf(dur, sizeof(dur), "%ld hour(s), %ld minute(s)",
-			upt / 3600, (upt / 60) % 60);
-	else if(upt < (360000l))
-		snprintf(dur, sizeof(dur), "%ld hours", upt / 3600);
-	else
-		snprintf(dur, sizeof(dur), "%ld days", upt / (3600l * 24l));
-
-	if(!sl || !*sl)
-		sl = "up";
-
-#ifndef	VERSION
-#define	VERSION "w32"
-#endif
-
-	snprintf(buffer, sizeof(buffer),
-		"<HR>Bayonne server version " VERSION "; node=%s timeslots=%d service level=%s; running %s<BR>\r\n", 
-		server->getLast("servername"), ts_used, sl, dur);
-	sendText(buffer);
-	sendText("</BODY></HTML>\r\n");
-	sendText("\r\n");
+	htmlInsert("footer.part", NULL);
+        sendText("</BODY></HTML>\r\n");
+        sendText("\r\n");
 	syncExit();
 }
 
@@ -67,7 +151,10 @@ void Session::htmlHeader(const char *title, bool refresh)
 			Service::webservice.getLast("refresh"));
 		sendText(buffer);
 	}
-	sendText("</HEAD><BODY>\r\n");
+	sendText("</HEAD>\r\n");
+	htmlInsert("header.part", title);
+//	snprintf(buffer, sizeof(buffer), "<BODY><H1>%s</H1><P>\r\n", title); 
+//	sendText(buffer);
 }
 
 void Session::htmlCalls(void)
@@ -76,7 +163,6 @@ void Session::htmlCalls(void)
 	timeslot_t index = 0;
 
 	htmlHeader("Bayonne Calls", true);
-	sendText("<H1>Bayonne Calls</H1><P>\r\n");
 	sendText("<TABLE border=\"1\" summary=\"Active Calls\">\r\n");
 	sendText("<CAPTION><EM>Active Calls</EM></CAPTION>\r\n");
 	sendText("<TR><TH>Session<TH>Parent<TH>Type<TH>Time<TH>Duration<TH>From<TH>Caller<TH>Line\r\n");
@@ -149,7 +235,6 @@ void Session::htmlControl(void)
 	}
 
 	htmlHeader("Bayonne Control", false);
-	sendText("<H1>Bayonne Control</H1><P>\r\n");
 
 	if(!cmd)
 	{
@@ -297,7 +382,6 @@ void Session::htmlStatus(void)
 
 	time(&tb);
 	htmlHeader("Bayonne Status", true);
-	sendText("<H1>Bayonne Status</H1><P>\r\n");
 
 	sendText("<TABLE border=\"1\" summary=\"Installed Drivers\">\r\n");
 	sendText("<CAPTION><EM>Drivers loaded into server</EM></CAPTION>\r\n");
