@@ -25,8 +25,12 @@ Service Service::webservice;
 bool Service::active = false;
 
 Service::Service() :
-BayonneService(0, 0), Keydata("/bayonne/module/webservice")
+BayonneService(0, 0), 
+BayonneZeroconf("_http._tcp"),
+Keydata("/bayonne/module/webservice")
 {
+	const char *cp;
+
 	static Keydata::Define defkeys[] = {
 	{"interface", "127.0.0.1"},
 	{"port", "8055"},
@@ -37,6 +41,7 @@ BayonneService(0, 0), Keydata("/bayonne/module/webservice")
 	{"refresh", "10"},
 	{"realm", "bayonne"},
 	{"datafiles", WEBSERVER_FILES}, 
+	{"zeroconf", "yes"},
 	{NULL, NULL}};
 
 	if(Bayonne::getUserdata())
@@ -46,6 +51,16 @@ BayonneService(0, 0), Keydata("/bayonne/module/webservice")
 #ifdef	WIN32
 	loadFile("C:\\Program Files\\GNU Telephony\\Bayonne Config\\module.ini", "webservice");
 #endif
+	cp = getLast("zeroconf");
+	switch(*cp)
+	{
+	case 'y':
+	case 'Y':
+	case 't':
+	case 'T':
+	case '1':
+		zeroconf_port = atoi(getLast("port"));
+	}
 }
 
 void Service::stopService(void)
@@ -62,6 +77,7 @@ void Service::run(void)
 	const char *cp;
 	char *tok;
 	char *p = (char *)getLast("interface");
+	unsigned count = 0, ipv6_count = 0;
 
 	slog.info("webservice started");
 	
@@ -69,13 +85,22 @@ void Service::run(void)
 	while(cp)
 	{
 #ifdef	CCXX_IPV6
+		++count;
 		if(strchr(cp, ':'))
+		{
+			++ipv6_count;
 			new TCPV6(cp);
+		}
 		else
 #endif
 		new TCPV4(cp);
 		cp = strtok_r(NULL, " ,;\t", &tok);
 	}
+
+	if(count && ipv6_count == count)
+		zeroconf_family = ZEROCONF_IPV6;
+	else if(count && !ipv6_count)
+		zeroconf_family = ZEROCONF_IPV4;
 	
 	for(;;)
 	{
