@@ -164,6 +164,19 @@ sub resume($$) {
 	return "invalid";
 }
 
+sub refer($$$) {
+	my($self,$sid,$target) = @_;
+	my $query = "refer.xml";
+	$query .= "?session=" . uri_escape($sid);
+	$query .= "&target=" . uri_escape($target);
+	my $reply = $self->xmlreply($query);
+
+	if($reply) {
+		return $reply->{results}->{result}->{value};};
+
+	return undef;
+}
+
 sub session($$) {
 	my($self,$sid) = @_;
 	my $result = "failure";
