@@ -218,6 +218,7 @@ public:
 class Methods : public BayonneSession
 {
 public:
+	bool scrTrap(void);
 	bool scrBGM(void);
 	bool scrList(void);
 	bool scrEcho(void);
@@ -267,6 +268,7 @@ public:
 class Checks : public ScriptChecks, public Bayonne
 {
 public:
+	const char *chkTrap(Line *line, ScriptImage *img);
 	const char *chkSay(Line *line, ScriptImage *img);
         const char *chkEndinput(Line *line, ScriptImage *img); 
 	const char *chkBGM(Line *line, ScriptImage *img);
